"""Top-level package for anchors."""
from .score import get_guide_residuals, get_gene_residuals

__author__ = """Peter Carl DeWeirdt"""
__email__ = 'petedeweirdt@gmail.com'
__version__ = '0.3.0'
